﻿using GrapeCity.Windows.SpreadSheet.Data;
using System.Collections.Generic;
using System.Linq;
using System.Windows;

namespace SpreadCellFormat
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            spread.ActiveSheet.RowCount = 1;
            spread.ActiveSheet[0, 0].Value = 234;
            spread.ActiveSheet[0, 1].Value = 89;
            spread.ActiveSheet.ColumnCount = 5;
            spread.ActiveSheet.Cells[0, 0].Formatter = new GeneralFormatter(FormatMode.StandardNumericMode, "C");
            spread.ActiveSheet.Cells[0, 1].Formatter = new GeneralFormatter(FormatMode.StandardNumericMode, "N2");
        }

        private void AddRow(object sender, RoutedEventArgs e)
        {
            int addIndex = spread.ActiveSheet.ActiveRowIndex; // position where a new row will be added
            int rowCount = 1; // Number of rows to add
            spread.ActiveSheet.AddRows(addIndex, rowCount);
            CopyRowsFormat(addIndex + 1, Enumerable.Range(addIndex, rowCount).ToList());
        }

        /// <summary>
        /// copies format of one row to other rows
        /// </summary>
        /// <param name="rowFormatToCopy"></param>
        /// <param name="copyToRows"></param>
        public void CopyRowsFormat(int rowFormatToCopy, List<int> copyToRows)
        {
            foreach(var copyToRow in copyToRows)
            {
                for (int col = 0; col < spread.ActiveSheet.Columns.Count - 1; col++)
                {
                    var formatter = spread.ActiveSheet.Cells[rowFormatToCopy, col].Formatter;

                    if (formatter == null)
                        formatter = spread.ActiveSheet.Rows[rowFormatToCopy].Formatter;

                    if (formatter == null)
                        continue;

                    spread.ActiveSheet.Cells[copyToRow, col].Formatter = formatter;
                }
            }
        }

        /// <summary>
        /// copies format of one column to other columns
        /// </summary>
        /// <param name="rowFormatToCopy"></param>
        /// <param name="copyToRows"></param>
        public void SetColumnsFormat(int columnFormatToCopy, List<int> copyToColumns)
        {
            foreach (var copyToColumn in copyToColumns)
            {
                for (int row = 0; row < spread.ActiveSheet.Rows.Count - 1; row++)
                {
                    var formatter = spread.ActiveSheet.Cells[row, columnFormatToCopy].Formatter;

                    if (formatter == null)
                        formatter = spread.ActiveSheet.Columns[columnFormatToCopy].Formatter;

                    if (formatter == null)
                        continue;

                    spread.ActiveSheet.Cells[row, copyToColumn].Formatter = formatter;
                }
            }
        }
    }
}
